@@ -2,7 +2,7 @@ package Dist::Zilla::PluginBundle::Author::DOMM;
 
 # ABSTRACT: Dist::Zilla config suiting my needs
 
-our $VERSION = '0.911'; # VERSION
+our $VERSION = '0.912'; # VERSION
 
 use Moose;
 use namespace::autoclean;
@@ -52,10 +52,12 @@ has homepage => (
   lazy    => 1 ,
   default => sub { $_[0]->payload->{homepage} } ,
 );
-has issues => (
+
+has bugtracker => (
   is      => 'ro' ,
-  isa     => 'Bool' ,
-  lazy    => 0,
+  isa     => 'Maybe[Str]' ,
+  lazy    => 1,
+  default => sub { $_[0]->payload->{bugtracker} } ,
 );
 
 sub configure {
@@ -103,7 +105,7 @@ sub configure {
             ($self->homepage ? (homepage => $self->homepage) : ()),
         }],
         ['SourceHutMeta' => {
-            issues => $self->issues,
+            bugtracker => $self->bugtracker,
             ($self->homepage ? (homepage => $self->homepage) : ()),
         }],
         [ 'Git::Check' => {
@@ -142,7 +144,7 @@ Dist::Zilla::PluginBundle::Author::DOMM - Dist::Zilla config suiting my needs
 
 =head1 VERSION
 
-version 0.911
+version 0.912
 
 =head1 DESCRIPTION
 
